import octofuss
from django.db.models import Max
import octofussd.data.models as om


class ServerInfo(octofuss.Tree):
    keyword_doc = {
        "organization": "Organization configured in octofussd",
        "kernel_version": "Current kernel version",
        "ram_mbyte": "Total ram size in megabytes",
        "last_seen_clients": "Last client connected"
    }

    def __init__(self, name = None, **kw):
        super(ServerInfo, self).__init__(name, doc="Server information")
        self.conf = kw.get("conf", None)
        self.data = {}
        if self.conf:
            if self.conf.has_option("General", "organization"):
                self.data['organization'] = self.conf.get("General", "organization")
            else:
                self.data['organization'] = "NOT CONFIGURED"

        self.data['kernel_version'] = open("/proc/version").readline().split()[2].strip()
        self.data['ram_mbyte'] = int(int(open("/proc/meminfo").readline().split()[1].strip())/1024)

        ls_data = om.ClientActivity.objects.values("hostname").annotate(last=Max("timestamp"))[:10]
        self.data['last_seen_clients'] = [(x.get("hostname", "Unknown"), x.get("last").strftime("%Y-%m-%d %H:%M")) for x in ls_data]

    def lhas(self, path):
        if len(path) == 0: return True
        if len(path) > 1: return False
        return path[0] in self.data

    def lget(self, path):
        if len(path) == 0: return self.data
        if len(path) > 1: return super(ServerInfo, self).lget(path)
        return self.data[path[0]]

    def llist(self, path):
        if len(path) == 0: return list(self.data.keys())
        return []

    def ldoc(self, path):
        if len(path) == 0: return super(ServerInfo, self).ldoc(path)
        if len(path) > 1: return None
        return self.keyword_doc.get(path[0], None)


def init(**kw):
    conf = kw.get("conf", None)

    yield dict(
        tree = ServerInfo("serverinfo", conf=conf),
        root = "/"
        )
